package org.expressolivre.cte.calendar.adicionar;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import org.expressolivre.cte.common.BaseCalendarTestCase;
import org.expressolivre.cte.pages.calendar.AppointmentPage;
import org.expressolivre.cte.pages.calendar.CalendarTodayViewPage;
import org.testng.annotations.Optional;
import org.testng.annotations.Parameters;
import org.testng.annotations.Test;

/**
 * Suite:[FUN03.2] Adicionar Compromisso
 * 
 * Caso de Teste: EL-946:Adicionar compromisso com repeticao anual
 * 
 * Link: http://testlink.expressolivre.org/linkto.php?tprojectPrefix=EL&item=
 * testcase&id=EL-946
 * 
 * @author L.F.Estivalet (Serpro)
 * 
 *         Created on Ago 8, 2011 at 4:39:08 PM
 * 
 */
public class AdicionarCompromissoComRepeticaoAnualTestCase extends
		BaseCalendarTestCase {

	@Parameters({ "tipo", "titulo", "descricao", "local", "dataInicial",
			"horaInicial", "minutoInicial", "horaFinal", "minutoFinal",
			"prioridade", "dataFinal" })
	@Test
	public void adicionarCompromissoComRepeticaoAnual(
			@Optional("Normal") String tipo, String titulo,
			@Optional("") String descricao, @Optional("") String local,
			@Optional("") String dataInicial, String horaInicial,
			String minutoInicial, String horaFinal, String minutoFinal,
			@Optional("Normal") String prioridade,
			@Optional("") String dataFinal) throws ParseException {

		Calendar cal = Calendar.getInstance();
		SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
		SimpleDateFormat sdf2 = new SimpleDateFormat("dd/MM/yyyy");

		// Se a data inicial nao for informada, pega data corrente.
		if ("".equals(dataInicial)) {
			dataInicial = sdf2.format(cal.getTime());
		}
		// Transforma a data inicial informada (dd/MM/yyyy) para (yyyyMMdd)
		Date dtIni = sdf2.parse(dataInicial);
		cal.setTime(dtIni);

		// Adiciona 3 anos a data atual para recorrencia.
		cal.add(Calendar.YEAR, 3);
		dataFinal = sdf2.format(cal.getTime());

		AppointmentPage ap = super.newAppointment(sdf.format(dtIni));
		ap.setType(tipo);
		ap.setTitle(titulo);
		ap.setDescription(descricao);
		ap.setLocation(local);
		ap.setStartDate(dataInicial);
		ap.setStartHour(horaInicial);
		ap.setStartMinute(minutoInicial);
		ap.setEndDate(dataInicial);
		ap.setEndHour(horaFinal);
		ap.setEndMinute(minutoFinal);
		ap.setPriority(prioridade);
		ap.setRecurType("Anualmente");
		ap.setRptUseEnd(dataFinal);

		ap.saveAppointment();

		// Verificar se foram gerados 4 compromissos (o de hoje e dos proximos 3
		// anos).
		for (int i = 0; i < 4; i++) {
			CalendarTodayViewPage ctvp = super.openTodayView(sdf.format(cal
					.getTime()));
			ctvp.isTextPresent(titulo);
			cal.add(Calendar.YEAR, -1);
		}

	}
}
